Questa guida mostra come gestire Vertex ML Metadata.
Prima di iniziare
La prima volta che utilizzi Vertex ML Metadata in un progettoGoogle Cloud , Gemini Enterprise Agent Platform crea l'archivio dei metadati del progetto.
Se vuoi che i tuoi metadati vengano criptati utilizzando chiavi di crittografia gestite dal cliente (CMEK), devi creare l'archivio dei metadati utilizzando una CMEK prima di utilizzare Vertex ML Metadata per monitorare o analizzare i metadati. Segui le istruzioni per creare un archivio di metadati che utilizza una CMEK per configurare l'archivio di metadati del progetto.
Gestione degli elementi
Creazione di un artefatto
Utilizza REST o l'SDK Vertex AI Python per creare un artefatto.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: il tuo ID progetto
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creato l'artefatto.
Il datastore dei metadati predefinito è denominato
default. - ARTIFACT_ID: (facoltativo) l'ID del record dell'artefatto. Se l'ID artefatto non è specificato, Vertex ML Metadata crea un identificatore univoco per questo artefatto.
- DISPLAY_NAME: (facoltativo) il nome dell'artefatto definito dall'utente.
- URI: (facoltativo) la località in cui è archiviato l'artefatto
- ARTIFACT_STATE: (facoltativo) un valore dell'enumerazione State che rappresenta lo stato attuale dell'artefatto. Questo campo è gestito dalle applicazioni client. Vertex ML Metadata non verifica la validità delle transizioni di stato.
- METADATA_SCHEMA_TITLE: il titolo dello schema che descrive il campo dei metadati. Il titolo dello schema deve rispettare il formato "
. ". Lo spazio dei nomi deve iniziare con una lettera minuscola, può contenere caratteri minuscoli e numeri e può avere una lunghezza compresa tra due e venti caratteri. Il nome dello schema deve iniziare con una lettera maiuscola, può includere lettere e numeri e può avere una lunghezza compresa tra 2 e 49 caratteri. - METADATA_SCHEMA_VERSION: (Facoltativo) La versione dello schema che descrive il campo dei metadati.
schema_versiondeve essere una stringa di tre numeri separati da punti, ad esempio 1.0.0, 1.0.1. Questo formato consente di ordinare e confrontare le versioni. - METADATA: (Facoltativo) Proprietà che descrivono l'artefatto, ad esempio il tipo di set di dati.
- DESCRIPTION: (facoltativo) una stringa leggibile che descrive lo scopo dell'esecuzione da creare.
- LABELS:facoltativo. Metadati definiti dall'utente per organizzare gli artefatti.
Metodo HTTP e URL:
POST https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/artifacts?artifactId=ARTIFACT_ID
Corpo JSON della richiesta:
{
"displayName": "DISPLAY_NAME",
"uri": "URI",
"state": "ARTIFACT_STATE",
"schemaTitle": "METADATA_SCHEMA_TITLE",
"schemaVersion": "METADATA_SCHEMA_VERSION",
"metadata": {
METADATA
},
"labels": {"LABEL_1":"LABEL_2"},
"description": "DESCRIPTION"
}
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti ricevere una risposta JSON simile alla seguente:
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/default/artifacts/ARTIFACT_ID",
"displayName": "Example artifact",
"uri": "gs://your_bucket_name/artifacts/dataset.csv",
"etag": "67891011",
"labels": {
"test_label": "test_label_value"
},
"createTime": "2021-05-18T00:29:24.344Z",
"updateTime": "2021-05-18T00:29:24.344Z",
"state": "LIVE",
"schemaTitle": "system.Dataset",
"schemaVersion": "0.0.1",
"metadata": {
"payload_format": "CSV"
},
"description": "Description of the example artifact."
}
Python
Python
project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.uri: (Facoltativo) L'identificatore di risorsa uniforme per il file dell'artefatto, se presente. Può essere vuoto se non esiste un file dell'artefatto effettivo.artifact_id: (facoltativo) l'ID del record dell'artefatto. Se l'ID artefatto non è specificato, Vertex ML Metadata crea un identificatore univoco per questo artefatto.display_name: (facoltativo) il nome dell'artefatto definito dall'utente.schema_version: la versione dello schema che descrive il campo dei metadati.description: (facoltativo) una stringa leggibile che descrive lo scopo dell'artefatto da creare.metadata: proprietà che descrivono l'artefatto, ad esempio i parametri dell'artefatto.
Cerca un artefatto esistente
Gli artefatti rappresentano i dati utilizzati o prodotti dal flusso di lavoro ML, come set di dati e modelli. Per cercare un artefatto esistente, utilizza REST o l'SDK Agent Platform per Python.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creato l'artefatto.
Il datastore dei metadati predefinito è denominato
default. - PAGE_SIZE: (Facoltativo) Il numero massimo di artefatti da restituire. Se questo valore non viene specificato, il servizio restituisce un massimo di 100 record.
- PAGE_TOKEN: (facoltativo) un token di pagina di una chiamata MetadataService.ListArtifacts precedente. Specifica questo token per visualizzare la pagina di risultati successiva.
FILTER: specifica le condizioni necessarie per includere un artefatto nel set di risultati.
Metodo HTTP e URL:
GET https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/artifacts?pageSize=PAGE_SIZE&pageToken=PAGE_TOKEN&filter=FILTER
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. ARTIFACT_ID è l'ID del record dell'artefatto.
{
"artifacts": [
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/default/artifacts/ARTIFACT_ID",
"displayName": "Example artifact",
"uri": "gs://your_bucket_name/artifacts/dataset.csv",
"etag": "67891011",
"createTime": "2021-05-18T00:33:13.833Z",
"updateTime": "2021-05-18T00:33:13.833Z",
"state": "LIVE",
"schemaTitle": "system.Dataset",
"schemaVersion": "0.0.1",
"metadata": {
"payload_format": "CSV"
},
"description": "Description of the example artifact."
},
{
"name": "projects/PROJECT_ID/locations/LOCATION/metadataStores/METADATA_STORE/artifacts/ARTIFACT_ID",
"displayName": "Another example artifact",
"uri": "gs://your_bucket_name/artifacts/dataset-2.csv",
"etag": "67891012",
"createTime": "2021-05-18T00:29:24.344Z",
"updateTime": "2021-05-18T00:29:24.344Z",
"state": "LIVE",
"schemaTitle": "system.Dataset",
"schemaVersion": "0.0.1",
"metadata": {
"payload_format": "CSV"
},
"description": "Description of the other example artifact."
}
]
}
Python
Python
project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.display_name_filter: filtro da applicare al nome visualizzato durante l'elenco delle risorse con il formato "display_name=\"my_filter\"" .create_date_filter: filtro da applicare al nome create_date durante l'elenco delle risorse con il formato "create_time>\"2022-06-11T12:30:00-08:00\"".
Elimina un artefatto esistente
Utilizza REST o l'SDK Vertex AI Python per eliminare un artefatto.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creato l'artefatto.
Il datastore dei metadati predefinito è denominato
default. - ARTIFACT_ID: l'ID del record dell'artefatto da eliminare.
Metodo HTTP e URL:
DELETE https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/artifacts/ARTIFACT_ID
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. Puoi utilizzare OPERATION_ID nella risposta per ottenere lo stato dell'operazione.
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/artifacts/ARTIFACT_ID/operations/OPERATION_ID",
"metadata": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.DeleteOperationMetadata",
"genericMetadata": {
"createTime": "2021-07-21T20:05:30.179713Z",
"updateTime": "2021-07-21T20:05:30.179713Z"
}
},
"done": true,
"response": {
"@type": "type.googleapis.com/google.protobuf.Empty"
}
}
Python
Python
artifact_id: l'ID del record di esecuzione.project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.
Elimina definitivamente gli artefatti
Segui le istruzioni riportate di seguito per eliminare più artefatti in base a una condizione di filtro.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creato l'artefatto.
Il datastore dei metadati predefinito è denominato
default. -
FILTER: specifica le condizioni richieste per l'eliminazione degli artefatti. Ad esempio:
- Filtra tutti gli artefatti che contengono example nel nome visualizzato:
"display_name = \"*example*\"". - Filtra tutti gli artefatti creati prima del 19/11/2020T11:30:00-04:00:
"create_time < \"2020-11-19T11:30:00-04:00\"".
- Filtra tutti gli artefatti che contengono example nel nome visualizzato:
- FORCE: indica se eseguire o meno l'eliminazione effettiva. Se il flag è impostato su false, il metodo restituirà un campione di nomi di artefatti che verrebbero eliminati.
Metodo HTTP e URL:
POST https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/artifacts:purge
Corpo JSON della richiesta:
{
"filter": "FILTER",
"force": FORCE
}
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. Puoi utilizzare OPERATION_ID nella risposta per ottenere lo stato dell'operazione.
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/operations/OPERATION_ID",
"metadata": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.PurgeArtifactsMetadata",
"genericMetadata": {
"createTime": "2021-07-21T21:02:33.757991Z",
"updateTime": "2021-07-21T21:02:33.757991Z"
}
},
"done": true,
"response": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.PurgeArtifactsResponse",
"purgeCount": "15"
}
}
Gestione dell'esecuzione
Creazione di un'esecuzione
Le esecuzioni rappresentano un passaggio del flusso di lavoro ML. Utilizza REST o l'SDK Vertex AI Python per creare un'esecuzione.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creata l'esecuzione.
Il datastore dei metadati predefinito è denominato
default. - EXECUTION_ID: l'ID del record di esecuzione. Se l'ID esecuzione non viene specificato, Vertex ML Metadata crea un identificatore univoco per l'esecuzione.
- DISPLAY_NAME: il nome visualizzato dell'esecuzione. Questo campo può contenere fino a 128 caratteri Unicode.
- EXECUTION_STATE: (facoltativo) un valore dell'enumerazione State che rappresenta lo stato attuale dell'esecuzione. Questo campo è gestito dalle applicazioni client. Vertex ML Metadata non verifica la validità delle transizioni di stato.
- METADATA_SCHEMA_TITLE: il titolo dello schema che descrive il campo dei metadati. Il titolo dello schema deve rispettare il formato "
. ". Lo spazio dei nomi deve iniziare con una lettera minuscola, può contenere caratteri minuscoli e numeri e può avere una lunghezza compresa tra due e venti caratteri. Il nome dello schema deve iniziare con una lettera maiuscola, può includere lettere e numeri e può avere una lunghezza compresa tra 2 e 49 caratteri. - METADATA_SCHEMA_VERSION: (Facoltativo) La versione dello schema che descrive il campo dei metadati.
schema_versiondeve essere una stringa di tre numeri separati da punti, ad esempio 1.0.0, 1.0.1. Questo formato consente di ordinare e confrontare le versioni. - METADATA: (facoltativo) proprietà che descrivono l'esecuzione, ad esempio i parametri di esecuzione.
- DESCRIPTION: (facoltativo) una stringa leggibile che descrive lo scopo dell'esecuzione da creare.
- LABELS: (Facoltativo) Metadati definiti dall'utente per organizzare le esecuzioni.
Metodo HTTP e URL:
POST https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/executions?executionId=EXECUTION_ID
Corpo JSON della richiesta:
{
"displayName": "DISPLAY_NAME",
"state": "EXECUTION_STATE",
"schemaTitle": "METADATA_SCHEMA_TITLE",
"schemaVersion": "METADATA_SCHEMA_VERSION",
"metadata": {
METADATA
},
"labels": {"LABEL_1":"LABEL_2"},
"description": "DESCRIPTION"
}
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti ricevere una risposta JSON simile alla seguente:
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/executions/EXECUTION_ID",
"displayName": "Example Execution",
"etag": "67891011",
"labels": {
"test_label": "test_label_value"
},
"createTime": "2021-05-18T00:04:49.659Z",
"updateTime": "2021-05-18T00:04:49.659Z",
"schemaTitle": "system.Run",
"schemaVersion": "0.0.1",
"metadata": {},
"description": "Description of the example execution."
}
Python
Python
display_name: il nome visualizzato dell'esecuzione. Questo campo può contenere fino a 128 caratteri Unicode.input_artifacts: un elenco di una o più istanze di aiplatform.Artifact che rappresentano un artefatto di input.output_artifacts: un elenco di una o più istanze di aiplatform.Artifact che rappresentano un artefatto di output.project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.execution_id: l'ID del record di esecuzione. Se l'ID esecuzione non viene specificato, Vertex ML Metadata crea un identificatore univoco per l'esecuzione.metadata: proprietà che descrivono l'esecuzione, ad esempio i parametri di esecuzione.schema_version:la versione dello schema che descrive il campo dei metadati.description: (facoltativo) una stringa leggibile che descrive lo scopo dell'esecuzione da creare.
Cerca un'esecuzione esistente
Utilizza REST o l'SDK Vertex AI Python per cercare un'esecuzione esistente.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creata l'esecuzione.
Il datastore dei metadati predefinito è denominato
default. - PAGE_SIZE: (Facoltativo) Il numero massimo di artefatti da restituire. Se questo valore non viene specificato, il servizio restituisce un massimo di 100 record.
- PAGE_TOKEN: (facoltativo) un token di pagina di una chiamata MetadataService.ListArtifacts precedente. Specifica questo token per visualizzare la pagina di risultati successiva.
FILTER: specifica le condizioni richieste per includere un'esecuzione nel set di risultati.
Metodo HTTP e URL:
GET https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/executions?pageSize=PAGE_SIZE&pageToken=PAGE_TOKEN&filter=FILTER
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. EXECUTION_ID è l'ID del record di esecuzione.
{
"executions": [
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/executions/EXECUTION_ID",
"displayName": "Example execution 1",
"etag": "67891011",
"createTime": "2021-05-18T00:06:56.177Z",
"updateTime": "2021-05-18T00:06:56.177Z",
"schemaTitle": "system.Run",
"schemaVersion": "0.0.1",
"metadata": {},
"description": "Description of the example execution."
},
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/executions/EXECUTION_ID",
"displayName": "Example execution 2",
"etag": "67891011",
"createTime": "2021-05-18T00:04:49.659Z",
"updateTime": "2021-05-18T00:04:49.659Z",
"schemaTitle": "system.Run",
"schemaVersion": "0.0.1",
"metadata": {},
"description": "Description of the example execution."
}
]
}
Python
Python
execution_id: l'ID del record di esecuzione.project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.
Elimina un'esecuzione esistente
Utilizza REST o l'SDK Vertex AI Python per eliminare un'esecuzione.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creata l'esecuzione.
Il datastore dei metadati predefinito è denominato
default. - EXECUTION_ID: l'ID del record di esecuzione da eliminare.
Metodo HTTP e URL:
DELETE https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/executions/EXECUTION_ID
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. Puoi utilizzare OPERATION_ID nella risposta per ottenere lo stato dell'operazione.
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/executions/EXECUTION_ID/operations/OPERATION_ID",
"metadata": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.DeleteOperationMetadata",
"genericMetadata": {
"createTime": "2021-07-21T20:05:30.179713Z",
"updateTime": "2021-07-21T20:05:30.179713Z"
}
},
"done": true,
"response": {
"@type": "type.googleapis.com/google.protobuf.Empty"
}
}
Python
Python
execution_id: l'ID del record di esecuzione.project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.
Elimina definitivamente le esecuzioni
Per eliminare più esecuzioni in base a un filtro, segui le istruzioni riportate di seguito.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creata l'esecuzione.
Il datastore dei metadati predefinito è denominato
default. -
FILTER: specifica le condizioni richieste per l'eliminazione delle esecuzioni. Ad esempio:
- Filtra tutte le esecuzioni che contengono example nel nome visualizzato:
"display_name = \"*example*\"". - Filtra per tutte le esecuzioni create prima del giorno 2020-11-19T11:30:00-04:00:
"create_time < \"2020-11-19T11:30:00-04:00\"".
- Filtra tutte le esecuzioni che contengono example nel nome visualizzato:
- FORCE: indica se eseguire o meno l'eliminazione effettiva. Se il flag è impostato su false, il metodo restituirà un campione di nomi di artefatti che verrebbero eliminati.
Metodo HTTP e URL:
POST https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/executions:purge
Corpo JSON della richiesta:
{
"filter": "FILTER",
"force": FORCE
}
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. Puoi utilizzare OPERATION_ID nella risposta per ottenere lo stato dell'operazione.
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/operations/OPERATION_ID",
"metadata": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.PurgeExecutionsMetadata",
"genericMetadata": {
"createTime": "2021-07-21T21:02:45.757991Z",
"updateTime": "2021-07-21T21:02:45.757991Z"
}
},
"done": true,
"response": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.PurgeExecutionsResponse",
"purgeCount": "2"
}
}
Gestione del contesto
Crea un contesto
I contesti consentono di raggruppare insiemi di artefatti ed esecuzioni. Utilizza REST o l'SDK Vertex AI Python per creare un contesto.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE:l'ID dell'archivio dei metadati in cui viene creata l'esecuzione.
Il datastore dei metadati predefinito è denominato
default. - CONTEXT_ID: (facoltativo) l'ID del record di contesto. Se l'ID contesto non è specificato, Vertex ML Metadata crea un identificatore univoco per questo contesto
- DISPLAY_NAME: il nome visualizzato del contesto. Questo campo può contenere fino a 128 caratteri Unicode.
- PARENT_CONTEXT: specifica il nome della risorsa per i contesti principali. Un contesto non può avere più di 10 contesti principali.
- METADATA_SCHEMA_TITLE: il titolo dello schema che descrive il campo dei metadati. Il titolo dello schema deve rispettare il formato "
. ". Lo spazio dei nomi deve iniziare con una lettera minuscola, può contenere caratteri minuscoli e numeri e può avere una lunghezza compresa tra due e venti caratteri. Il nome dello schema deve iniziare con una lettera maiuscola, può includere lettere e numeri e può avere una lunghezza compresa tra 2 e 49 caratteri. - METADATA_SCHEMA_VERSION: (Facoltativo) La versione dello schema che descrive il campo dei metadati.
schema_versiondeve essere una stringa di tre numeri separati da punti, ad esempio 1.0.0, 1.0.1. Questo formato consente di ordinare e confrontare le versioni. - METADATA: proprietà che descrivono il contesto, ad esempio i parametri di contesto.
- DESCRIPTION:(facoltativo) una stringa leggibile che descrive lo scopo dell'esecuzione da creare.
- LABELS: (Facoltativo) Metadati definiti dall'utente per organizzare i contesti.
Metodo HTTP e URL:
POST https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/contexts?contextId=CONTEXT_ID
Corpo JSON della richiesta:
{
"displayName": "DISPLAY_NAME:",
"parentContexts": [
"PARENT_CONTEXT_1",
"PARENT_CONTEXT_2"
],
"schemaTitle": "METADATA_SCHEMA_TITLE",
"schemaVersion": "METADATA_SCHEMA_VERSION",
"metadata": {
METADATA
},
"labels": {"LABEL_1":"LABEL_2"},
"description": "DESCRIPTION"
}
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. CONTEXT_ID è l'ID del record di contesto.
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/contexts/CONTEXT_ID",
"displayName": "Example context:",
"etag": "67891011",
"labels": {
"test_label": "test_label_value"
},
"createTime": "2021-05-18T01:52:51.642Z",
"updateTime": "2021-05-18T01:52:51.642Z",
"schemaTitle": "system.Experiment",
"schemaVersion": "0.0.1",
"metadata": {},
"description": "Description of the example context."
}
Python
Python
display_name: il nome visualizzato del contesto. Questo campo può contenere fino a 128 caratteri Unicode.project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.context_id: (facoltativo) l'ID del record di contesto.metadata: proprietà che descrivono il contesto, ad esempio i parametri di contesto.schema_version: la versione dello schema che descrive il campo dei metadati.description: (facoltativo) una stringa leggibile che descrive lo scopo del contesto da creare.
Cerca un contesto esistente
Utilizza REST o l'SDK Vertex AI Python per cercare un contesto esistente.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creato il contesto.
Il datastore dei metadati predefinito è denominato
default. - PAGE_SIZE: (Facoltativo) Il numero massimo di artefatti da restituire. Se questo valore non viene specificato, il servizio restituisce un massimo di 100 record.
- PAGE_TOKEN: (facoltativo) un token di pagina di una chiamata MetadataService.ListArtifacts precedente. Specifica questo token per visualizzare la pagina di risultati successiva.
FILTER: specifica le condizioni necessarie per includere un contesto nel set di risultati.
Metodo HTTP e URL:
GET https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/contexts?pageSize=PAGE_SIZE&pageToken=PAGE_TOKEN&filter=FILTER
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. CONTEXT_ID è l'ID del record di contesto.
{
"contexts": [
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/contexts/CONTEXT_ID",
"displayName": "Experiment 1",
"etag": "67891011",
"createTime": "2021-05-18T22:36:02.153Z",
"updateTime": "2021-05-18T22:36:02.153Z",
"parentContexts": [],
"schemaTitle": "system.Experiment",
"schemaVersion": "0.0.1",
"metadata": {}
},
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/contexts/CONTEXT_ID",
"displayName": "Pipeline run 1",
"etag": "67891011",
"createTime": "2021-05-18T22:35:02.600Z",
"updateTime": "2021-05-18T22:35:02.600Z",
"parentContexts": [],
"schemaTitle": "system.PipelineRun",
"schemaVersion": "0.0.1",
"metadata": {}
}
]
}
Python
Python
context_id:: l'ID del record di contesto.project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.
Elimina un contesto esistente
Utilizza REST o l'SDK Vertex AI Python per eliminare un contesto.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE: l'ID dell'archivio dei metadati in cui viene creato il contesto.
Il datastore dei metadati predefinito è denominato
default. - CONTEXT_ID: (facoltativo) l'ID del record di contesto.
Metodo HTTP e URL:
DELETE https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/contexts/CONTEXT_ID
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. Puoi utilizzare OPERATION_ID nella risposta per ottenere lo stato dell'operazione.
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/contexts/CONTEXT_ID/operations/OPERATION_ID",
"metadata": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.DeleteOperationMetadata",
"genericMetadata": {
"createTime": "2021-07-21T20:05:30.179713Z",
"updateTime": "2021-07-21T20:05:30.179713Z"
}
},
"done": true,
"response": {
"@type": "type.googleapis.com/google.protobuf.Empty"
}
}
Python
Python
context_id:: l'ID del record di contesto.project: . Puoi trovare questi ID nella pagina di benvenuto della console Google Cloud .location: consulta l'elenco delle località disponibili.
Elimina definitivamente i contesti
Segui le istruzioni riportate di seguito per eliminare più contesti in base a una condizione di filtro.
REST
Prima di utilizzare i dati della richiesta, apporta le sostituzioni seguenti:
- LOCATION_ID: la tua regione.
- PROJECT_ID: .
- METADATA_STORE:l'ID dell'archivio dei metadati in cui viene creato il contesto.
Il datastore dei metadati predefinito è denominato
default. -
FILTER: specifica le condizioni richieste dai contesti da eliminare. Ad esempio:
- Filtra tutti i contesti che contengono example nel nome visualizzato:
"display_name = \"*example*\"". - Filtri per tutti i contesti creati prima del giorno 2020-11-19T11:30:00-04:00:
"create_time < \"2020-11-19T11:30:00-04:00\"".
- Filtra tutti i contesti che contengono example nel nome visualizzato:
- FORCE: indica se eseguire o meno l'eliminazione effettiva. Se il flag è impostato su false, il metodo restituirà un campione di nomi di contesto che verrebbero eliminati.
Metodo HTTP e URL:
POST https://LOCATION_ID-aiplatform.googleapis.com/v1/projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/contexts:purge
Corpo JSON della richiesta:
{
"filter": "FILTER",
"force": FORCE
}
Per inviare la richiesta, espandi una di queste opzioni:
Dovresti vedere un output simile al seguente. Puoi utilizzare OPERATION_ID nella risposta per ottenere lo stato dell'operazione.
{
"name": "projects/PROJECT_ID/locations/LOCATION_ID/metadataStores/METADATA_STORE/operations/OPERATION_ID",
"metadata": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.PurgeContextsMetadata",
"genericMetadata": {
"createTime": "2021-07-21T21:02:40.757991Z",
"updateTime": "2021-07-21T21:02:40.757991Z"
}
},
"done": true,
"response": {
"@type": "type.googleapis.com/google.cloud.aiplatform.v1.PurgeContextsResponse",
"purgeCount": "5"
}
}